@@ -136,7 +136,7 @@ def test_add_ut_const(ut1, const_or_scalar2):
 
 def test_add_lr(lr1, lr2):
     with ConditionalContext(
-        isinstance(lr1.left, Diagonal) or isinstance(lr2.left, Diagonal),
+        structured(lr1.left) or structured(lr2.left),
         AssertDenseWarning("indexing into <diagonal>"),
     ):
         check_bin_op(B.add, lr1, lr2, asserted_type=LowRank)
@@ -144,7 +144,7 @@ def test_add_lr(lr1, lr2):
 
 def test_add_lr_sign(lr_pd):
     with ConditionalContext(
-        isinstance(lr_pd.left, Diagonal), AssertDenseWarning("indexing into <diagonal>")
+        structured(lr_pd.left), AssertDenseWarning("indexing into <diagonal>")
     ):
         assert B.add(lr_pd, lr_pd).sign == 1
 
@@ -162,7 +162,7 @@ def test_add_lr_diag(lr1, diag2):
 
 def test_add_wb(wb1, wb2):
     with ConditionalContext(
-        isinstance(wb1.lr.left, Diagonal) or isinstance(wb2.lr.left, Diagonal),
+        structured(wb1.lr.left) or structured(wb2.lr.left),
         AssertDenseWarning("indexing into <diagonal>"),
     ):
         check_bin_op(B.add, wb1, wb2, asserted_type=Woodbury)
@@ -180,6 +180,10 @@ def test_add_wb_constant(wb1, const_or_scalar2):
 
 
 def test_add_wb_lr(wb1, lr2):
+    with ConditionalContext(
+            structured(wb1.lr.left) or structured(lr2.left),
+            AssertDenseWarning("indexing into <diagonal>"),
+    ):
         check_bin_op(B.add, wb1, lr2, asserted_type=Woodbury)
         check_bin_op(B.add, lr2, wb1, asserted_type=Woodbury)
 
